@@ -231,6 +231,8 @@
  *
  * \since version 3.17.2
  */
+#if !defined(WITHOUT_FREERDP_3x_DEPRECATED)
 /* #undef WITHOUT_FREERDP_3x_DEPRECATED */
+#endif
 
 #endif /* FREERDP_CONFIG_H */
